# SeleneXtra
Bringing additional features to Selenium.

## Installation
```
pip install selenextra
```

## Note
Add the ca.crt file to the Chrome browser to improve page loading speed and other options.
```
python -m seleniumwire extractcert
```
